import { App } from '@kevisual/router';
import { HttpsPem } from '@/module/assistant/https/sign.ts';
// import { AssistantConfig } from '@/module/assistant/index.ts';
import { AssistantInit, parseHomeArg } from '@/services/init/index.ts';
import { configDir as HomeConfigDir } from '@/module/assistant/config/index.ts';
import { useContextKey } from '@kevisual/use-config/context';

const manualParse = parseHomeArg(HomeConfigDir);
const _configDir = manualParse.configDir;
export const configDir = AssistantInit.detectConfigDir(_configDir);
const isInit = manualParse?.options?.help ? false : true;
export const assistantConfig = new AssistantInit({
  path: configDir,
  init: isInit,
});

const httpsPem = new HttpsPem(assistantConfig);

export const runtime = useContextKey('runtime', () => {
  return {
    type: 'client',
  };
});

export const app = useContextKey('app', () => {
  const init = isInit;
  if (init) {
    const config = assistantConfig.getConfig();
    if (config?.https?.type !== 'https') {
      return new App({
        serverOptions: {
          path: '/client/router',
          httpType: 'http',
        },
      });
    }
  }
  return new App({
    serverOptions: {
      path: '/client/router',
      httpType: 'https',
      httpsCert: httpsPem.cert,
      httpsKey: httpsPem.key,
    },
  });
});
