import { Query } from '@kevisual/query/query';
import { app, assistantConfig } from '../app.ts';
import './config/index.ts';
import './shop-install/index.ts';
import './ai/index.ts';

import os from 'node:os';

const checkAuth = async (ctx: any, isAdmin = false) => {
  const config = assistantConfig.getConfig();
  const { auth } = config;
  const host = config.pageApi || config.registry || 'https://kevisual.cn';
  const url = new URL('/api/router', host);
  const token = ctx.query.token;
  if (auth && auth.type !== 'public') {
    if (!token) {
      return ctx.throw(401, 'not login');
    }
    url.searchParams.set('token', token);
    // 鉴权代理
    // TODO:
    const query = new Query({ url: url.toString() });
    const res = await query.post({
      path: 'user',
      key: 'me',
    });
    if (res.code !== 200) {
      return ctx.throw(401, 'not login');
    }
    const tokenUser = res.data || {};
    ctx.state = {
      ...ctx.state,
      tokenUser,
    };
    const { username } = tokenUser;
    if (isAdmin) {
      if (auth.username && auth.username !== username) {
        return ctx.throw(403, 'not admin user');
      }
    }
  }
};
app
  .route({
    path: 'auth',
    id: 'auth',
    isDebug: true,
    description: '获取当前登录用户信息',
  })
  .define(async (ctx) => {
    await checkAuth(ctx);
  })
  .addTo(app);
app
  .route({
    path: 'admin-auth',
    id: 'admin-auth',
  })
  .define(async (ctx) => {
    await checkAuth(ctx, true);
  })
  .addTo(app);

app
  .route({
    path: 'client',
    key: 'version',
  })
  .define(async (ctx) => {
    ctx.body = 'v1.0.0';
  })
  .addTo(app);

app
  .route({
    path: 'client',
    key: 'time',
  })
  .define(async (ctx) => {
    ctx.body = {
      time: new Date().getTime(),
      date: new Date().toLocaleDateString(),
    };
  })
  .addTo(app);

app
  .route({
    path: 'client',
    key: 'system',
    description: '获取系统信息',
  })
  .define(async (ctx) => {
    const { platform, arch, release } = os;
    ctx.body = {
      platform: platform(),
      arch: arch(),
      release: release(),
    };
  })
  .addTo(app);
